@@ -1,24 +1,14 @@
 /*
-    Copyright (C) 2018 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2018 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KITINERARY_AIRPORTDBGENERATOR_H
 #define KITINERARY_AIRPORTDBGENERATOR_H
 
 #include <knowledgedb.h>
+#include "osmairportdb.h"
 #include "timezones.h"
 
 #include <QHash>
@@ -49,11 +39,14 @@ public:
         int tzOffset;
         KnowledgeDb::Coordinate coord;
     };
+
+    OSMAirportDb osmDb;
+
 private:
     bool fetchAirports();
     bool fetchCountries();
     void merge(Airport &lhs, const Airport &rhs);
-    void lookupTimezones();
+    void improveCoordinates();
     void indexNames();
 
     QHash<QUrl, Airport> m_airportMap;
@@ -61,8 +54,6 @@ private:
     // mapping IATA codes to indexed string fragments
     QMap<QString, QVector<QString>> m_labelMap;
 
-    Timezones m_tzDb;
-
     int m_iataCollisions = 0;
     int m_coordinateConflicts = 0;
     int m_countryConflicts = 0;
